@@ -20,7 +20,7 @@ class PipAdmin(object):
 
     def complete_menu(self):
         """
-        menu architecture:
+        menu example:
         menu = {'group :  {'label': 'Accueil'},
                           {'label': 'CRM', 'menu': [
                               {'label': 'Sociétés', 'url': 'list', 'path': '/Services(crm)/FilteredSociete', },
